@@ -1,14 +1,11 @@
-import pandas
-
 from pm4py import util as pmutil
-from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
 from pm4py.algo.discovery.dfg.variants import native, performance, freq_triples
 from pm4py.objects.conversion.log import converter as log_conversion
-from pm4py.objects.log.util import dataframe_utils
 from pm4py.util import xes_constants as xes_util
 from pm4py.util import exec_utils
 from pm4py.algo.discovery.parameters import Parameters
 from enum import Enum
+import pkgutil
 
 
 class Variants(Enum):
@@ -62,18 +59,26 @@ def apply(log, parameters=None, variant=DEFAULT_VARIANT):
     if parameters is None:
         parameters = {}
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_util.DEFAULT_NAME_KEY)
+    start_timestamp_key = exec_utils.get_param_value(Parameters.START_TIMESTAMP_KEY, parameters, None)
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, xes_util.DEFAULT_TIMESTAMP_KEY)
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, pmutil.constants.CASE_CONCEPT_NAME)
 
-    if isinstance(log, pandas.core.frame.DataFrame) and not variant == Variants.FREQ_TRIPLES:
-        log = dataframe_utils.convert_timestamp_columns_in_df(log, timest_columns=[
-            timestamp_key])
-        dfg_frequency, dfg_performance = df_statistics.get_dfg_graph(log, measure="both",
-                                                                     activity_key=activity_key,
-                                                                     timestamp_key=timestamp_key,
-                                                                     case_id_glue=case_id_glue)
-        if variant in [Variants.PERFORMANCE, Variants.PERFORMANCE_GREEDY]:
-            return dfg_performance
-        else:
-            return dfg_frequency
+    if pkgutil.find_loader("pandas"):
+        import pandas
+        from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
+        from pm4py.objects.log.util import dataframe_utils
+
+        if isinstance(log, pandas.core.frame.DataFrame) and not variant == Variants.FREQ_TRIPLES:
+            log = dataframe_utils.convert_timestamp_columns_in_df(log, timest_columns=[
+                timestamp_key])
+            dfg_frequency, dfg_performance = df_statistics.get_dfg_graph(log, measure="both",
+                                                                         activity_key=activity_key,
+                                                                         timestamp_key=timestamp_key,
+                                                                         case_id_glue=case_id_glue,
+                                                                         start_timestamp_key=start_timestamp_key)
+            if variant in [Variants.PERFORMANCE, Variants.PERFORMANCE_GREEDY]:
+                return dfg_performance
+            else:
+                return dfg_frequency
+
     return exec_utils.get_variant(variant).apply(log_conversion.apply(log, parameters, log_conversion.TO_EVENT_LOG), parameters=parameters)
