@@ -1,4 +1,4 @@
-from pm4py.objects.log.util import compression, insert_classifier, string_to_file, log, sampling, \
+from pm4py.objects.log.util import compression, insert_classifier, log, sampling, \
     sorting, index_attribute, get_class_representation, get_log_representation, get_prefixes, \
     get_log_encoded, interval_lifecycle, log_regex, basic_filter, func
 import pkgutil
